@@ -2,44 +2,26 @@ package Data::Printer::Filter;
 use strict;
 use warnings;
 use Data::Printer::Common;
-
-my %_filters_for   = ();
-my %_extras_for    = ();
+use Scalar::Util;
 
 sub import {
     my $caller = caller;
-    my $id = Data::Printer::Common::_object_id( \$caller );
 
+    my %_filters_for  = ();
     my $filter = sub {
-        my ($type, $code, $extra) = @_;
-
+        my ($name, $code) = @_;
         Data::Printer::Common::_die( "syntax: filter 'Class', sub { ... }" )
-          unless $type and $code and ref $code eq 'CODE';
+          unless defined $name
+              && defined $code
+              && Scalar::Util::reftype($code) eq 'CODE';
 
-        if ($extra) {
-            Data::Printer::Common::_die( 'extra filter field must be a hashref' )
-                unless ref $extra and ref $extra eq 'HASH';
-
-            $_extras_for{$id}{$type} = $extra;
-        }
-        else {
-            $_extras_for{$id}{$type} = {};
-        }
-
-        unshift @{ $_filters_for{$id}{$type} }, sub {
+        my $target = Data::Printer::Common::_filter_category_for($name);
+        unshift @{$_filters_for{$target}{$name}}, sub {
             my ($item, $ddp) = @_;
             $code->($item, $ddp);
         };
     };
 
-    my $filters = sub {
-        return $_filters_for{$id};
-    };
-
-    my $extras = sub {
-        return $_extras_for{$id};
-    };
-
     my $newline = sub {
 #TODO FIXME        return $properties{_linebreak} . (' ' x $properties{_current_indent});
     };
@@ -75,12 +57,12 @@ sub import {
         *{"$caller\::np"} = $imported_np;
         *{"$caller\::p"} = $imported_p;
 
-        *{"$caller\::_filter_list"}   = $filters;
-        *{"$caller\::_extra_options"} = $extras;
+        *{"$caller\::_filter_list"} = sub {
+            return \%_filters_for;
+        };
     }
 };
 
-
 1;
 __END__
 
